@@ -13,7 +13,7 @@
 ##############################################################################
 """Component Architecture configuration handlers
 
-$Id: zcml.py 109324 2010-02-22 22:48:31Z sidnei $
+$Id: zcml.py 109656 2010-03-04 19:49:14Z kobold $
 """
 __docformat__ = "reStructuredText"
 
@@ -45,7 +45,7 @@ def check_security_support():
             "supported because zope.security is not available")
 
 def handler(methodName, *args, **kwargs):
-    method = getattr(zope.component.getGlobalSiteManager(), methodName)
+    method = getattr(zope.component.getSiteManager(), methodName)
     method(*args, **kwargs)
 
 class IBasicComponentInformation(zope.interface.Interface):
